==> archive-Bate-1.0.0-sources.jar: com/gtis/archive/service/ArchiveService.java <==
package com.gtis.archive.service;

import com.gtis.archive.core.Model;
import com.gtis.archive.entity.Archive;
import com.gtis.archive.entity.Document;
import com.gtis.common.Page;
import org.hibernate.criterion.Criterion;
import org.hibernate.criterion.Order;

import java.util.List;

/**
 * 档案服务.
 * <p/>
 *
 * @author <a href="mailto:oxsean@gmail.com">sean yang</a>
 * @version V1.0, 2010-10-26
 */
public interface ArchiveService {
    /**
     * 获取案卷
     *
     * @param modelName 案卷模型名
     * @param id        案卷id
     * @return 案卷
     */
    Archive getArchive(String modelName, String id);

    /**
     * 获取卷内
     *
     * @param modelName 卷内模型名
     * @param id        卷内id
     * @return 卷内
     */
    Document getDocument(String modelName, String id);

    /**
     * 获取只有基本信息的案卷对象
     * @param id  案卷id
     * @return  案卷
     */
    Archive getSimpleArchive(String id);

    /**
     * 根据项目Id获取只有基本信息的案卷对象
     * @param proid
     * @return
     */
    Archive getSimpleArchiveByProId(String proid);

    /**
     *  获取只有基本信息的卷内对象
     * @param id 卷内id
     * @return  案卷
     */
    Document getSimpleDocument(String id);

    /**
     * 获取卷内的案卷信息
     *
     * @param modelName  卷内模型名
     * @param documentId 卷内id
     * @return 案卷
     */
    Archive getDocumentArchive(String modelName, String documentId);

    /**
     * 获取卷内的案卷信息
     *
     * @param document 卷内
     * @return 案卷
     */
    Archive getDocumentArchive(Document document);

    /**
     * 获取案卷的卷内列表
     *
     * @param modelName 案卷模型名
     * @param archiveId 案卷id
     * @return 卷内列表
     */
    List<Document> getArchiveDocuments(String modelName, String archiveId);

    /**
     * 获取案卷的卷内列表
     *
     * @param archive 案卷
     * @return 卷内列表
     */
    List<Document> getArchiveDocuments(Archive archive);

    /**
     * 根据模型名获取案卷模型
     *
     * @param modelName 模型名
     * @return 字段列表
     */
    Model getArchiveModel(String modelName);

    /**
     * 根据模型名获取卷内模型
     *
     * @param modelName 模型名
     * @return 字段列表
     */
    Model getDocumentModel(String modelName);

    /**
     * 根据模型名创建一个案卷实例
     *
     * @param modelName 案卷的模型名
     * @return 案卷
     */
    Archive newArchive(String modelName);

    /**
     * 根据模型名创建一个卷内实例
     *
     * @param modelName 案卷的模型名
     * @return 案卷
     */
    Document newDocument(String modelName);

    /**
     * 删除案卷
     *
     * @param modelName 案卷的模型名
     * @param ids       案卷id列表
     */
    void removeArchive(String modelName, String[] ids);

    /**
     * 删除卷内
     *
     * @param modelName 案卷的模型名
     * @param ids       卷内id列表
     */
    void removeDocument(String modelName, String[] ids);

    /**
     * 保存案卷
     *
     * @param archive 案卷
     * @return 安敢
     */
    Archive saveArchive(Archive archive);

    /**
     * 保存卷内
     *
     * @param document 卷内
     * @return 卷内
     */
    Document saveDocument(Document document);

    /**
     * 检索案卷
     *
     * @param modelName  案卷的模型名
     * @param criterions 检索条件
     * @param orders     排序
     * @param start      位置
     * @param limit      分页大小
     * @return 案卷列表page对象
     */
    Page<Archive> searchArchive(String modelName, List<? extends Criterion> criterions, List<Order> orders, int start, int limit);

    /**
     * 检索卷内
     *
     * @param modelName  案卷的模型名
     * @param criterions 检索条件
     * @param orders     排序
     * @param start      位置
     * @param limit      分页大小
     * @return 卷内列表page对象
     */
    Page<Document> searchDocument(String modelName, List<? extends Criterion> criterions, List<Order> orders, int start, int limit);

    /**
     * 获取案卷数量
     *
     * @param modelName  案卷的模型名
     * @param criterions 查询条件
     * @return 数量
     */
    int getArchiveCount(String modelName, List<? extends Criterion> criterions);

    /**
     *
     * @param modelName
     * @param criterions
     * @param orders
     * @param dwdm
     * @param start
     * @param limit
     * @return
     */
    Page<Archive> searchArchive(String modelName, List<? extends Criterion> criterions, List<Order> orders,String dwdm ,int start, int limit);

    /**
     * 获取满足条件的档案序列
     *
     * @return
     */
    List<Object> searchArchiveList(String modelName, List<? extends Criterion> criterions, List<Order> orders ,int start, int limit);

    /**
     * 获取分类号种类
     *
     * @return
     */
    String flhjs(String flhjs,String modelName);

    /**
     * 通过档号获取档案
     * @param dh 档号
     * @return archive
     */
    Archive getArchiveByDh(String dh);

    /**
     * 通过档号获取档案
     * @param ajh 案卷号
     * @return archive
     */
    Archive getArchiveByAjh(Integer ajh,String mlh);

    /**
     * 获取ajhs
     * @param room
     * @param carbinet
     * @param side
     * @param cell
     * @param box
     * @return
     */
    String getAjhs(String room,String carbinet,Integer side,Integer cell,Integer box);

    /**
     * 获取卷内最大顺序号的卷内档案
     * @param modelName
     * @param archiveId
     * @return
     */
    public Document getMaxSxhDocuments(String modelName, String archiveId);

    /**
     * 获取档案最大柜号
     * @return
     */
    public Integer getArchivePosition();

    /**
     * 根据柜号获取柜号中最大格号
     * @param setCabinetSno
     * @return
     */
    public Integer getMaxCellId(Integer setCabinetSno);

    /**
     * 根据格号获取最大盒号
     * @param cellId
     * @return
     */
    public Integer getMaxBox(Integer cellId,Integer cabinetSno );

    /**
     * 根据盒号判断该盒是否放满
     * @param boxId
     * @return
     */
    public boolean isBoxFull(Integer boxId,Integer cellId,Integer cabinetSno);

    /**
     * 判断格子是否已满
     * @param cellId
     * @param cabinetSno
     * @return
     */
    public boolean isCellFull(Integer cellId,Integer cabinetSno );
}

==> archive-Bate-1.0.2-sources.jar: com/gtis/archive/service/ArchiveService.java <==
package com.gtis.archive.service;

import com.gtis.archive.core.Model;
import com.gtis.archive.entity.Archive;
import com.gtis.archive.entity.Document;
import com.gtis.common.Page;
import org.hibernate.criterion.Criterion;
import org.hibernate.criterion.Order;

import java.util.List;

/**
 * 档案服务.
 * <p/>
 *
 * @author <a href="mailto:oxsean@gmail.com">sean yang</a>
 * @version V1.0, 2010-10-26
 */
public interface ArchiveService {
    /**
     * 获取案卷
     *
     * @param modelName 案卷模型名
     * @param id        案卷id
     * @return 案卷
     */
    Archive getArchive(String modelName, String id);

    /**
     * 获取卷内
     *
     * @param modelName 卷内模型名
     * @param id        卷内id
     * @return 卷内
     */
    Document getDocument(String modelName, String id);

    /**
     * 获取只有基本信息的案卷对象
     *
     * @param id 案卷id
     * @return 案卷
     */
    Archive getSimpleArchive(String id);

    /**
     * 根据项目Id获取只有基本信息的案卷对象
     *
     * @param proid
     * @return
     */
    Archive getSimpleArchiveByProId(String proid);

    /**
     * 获取只有基本信息的卷内对象
     *
     * @param id 卷内id
     * @return 案卷
     */
    Document getSimpleDocument(String id);

    /**
     * 获取卷内的案卷信息
     *
     * @param modelName  卷内模型名
     * @param documentId 卷内id
     * @return 案卷
     */
    Archive getDocumentArchive(String modelName, String documentId);

    /**
     * 获取卷内的案卷信息
     *
     * @param document 卷内
     * @return 案卷
     */
    Archive getDocumentArchive(Document document);

    /**
     * 获取案卷的卷内列表
     *
     * @param modelName 案卷模型名
     * @param archiveId 案卷id
     * @return 卷内列表
     */
    List<Document> getArchiveDocuments(String modelName, String archiveId);

    /**
     * 获取案卷的卷内列表
     *
     * @param archive 案卷
     * @return 卷内列表
     */
    List<Document> getArchiveDocuments(Archive archive);

    /**
     * 根据模型名获取案卷模型
     *
     * @param modelName 模型名
     * @return 字段列表
     */
    Model getArchiveModel(String modelName);

    /**
     * 根据模型名获取卷内模型
     *
     * @param modelName 模型名
     * @return 字段列表
     */
    Model getDocumentModel(String modelName);

    /**
     * 根据模型名创建一个案卷实例
     *
     * @param modelName 案卷的模型名
     * @return 案卷
     */
    Archive newArchive(String modelName);

    /**
     * 根据模型名创建一个卷内实例
     *
     * @param modelName 案卷的模型名
     * @return 案卷
     */
    Document newDocument(String modelName);

    /**
     * 删除案卷
     *
     * @param modelName 案卷的模型名
     * @param ids       案卷id列表
     */
    void removeArchive(String modelName, String[] ids);

    /**
     * 删除卷内
     *
     * @param modelName 案卷的模型名
     * @param ids       卷内id列表
     */
    void removeDocument(String modelName, String[] ids);

    /**
     * 保存案卷
     *
     * @param archive 案卷
     * @return 安敢
     */
    Archive saveArchive(Archive archive);

    /**
     * 保存卷内
     *
     * @param document 卷内
     * @return 卷内
     */
    Document saveDocument(Document document);

    /**
     * 检索案卷
     *
     * @param modelName  案卷的模型名
     * @param criterions 检索条件
     * @param orders     排序
     * @param start      位置
     * @param limit      分页大小
     * @return 案卷列表page对象
     */
    Page<Archive> searchArchive(String modelName, List<? extends Criterion> criterions, List<Order> orders, int start, int limit);

    /**
     * 检索卷内
     *
     * @param modelName  案卷的模型名
     * @param criterions 检索条件
     * @param orders     排序
     * @param start      位置
     * @param limit      分页大小
     * @return 卷内列表page对象
     */
    Page<Document> searchDocument(String modelName, List<? extends Criterion> criterions, List<Order> orders, int start, int limit);

    /**
     * 获取案卷数量
     *
     * @param modelName  案卷的模型名
     * @param criterions 查询条件
     * @return 数量
     */
    int getArchiveCount(String modelName, List<? extends Criterion> criterions);

    /**
     * @param modelName
     * @param criterions
     * @param orders
     * @param dwdm
     * @param start
     * @param limit
     * @return
     */
    Page<Archive> searchArchive(String modelName, List<? extends Criterion> criterions, List<Order> orders, String dwdm, int start, int limit);

    /**
     * 获取满足条件的档案序列
     *
     * @return
     */
    List<Object> searchArchiveList(String modelName, List<? extends Criterion> criterions, List<Order> orders, int start, int limit);

    /**
     * 获取分类号种类
     *
     * @return
     */
    String flhjs(String flhjs, String modelName);

    /**
     * 通过档号获取档案
     *
     * @param dh 档号
     * @return archive
     */
    Archive getArchiveByDh(String dh);

    /**
     * 通过档号获取档案
     *
     * @param ajh 案卷号
     * @return archive
     */
    Archive getArchiveByAjh(Integer ajh, String mlh);

    /**
     * 获取ajhs
     *
     * @param room
     * @param carbinet
     * @param side
     * @param cell
     * @param box
     * @return
     */
    String getAjhs(String room, String carbinet, Integer side, Integer cell, Integer box);

    /**
     * 获取卷内最大顺序号的卷内档案
     *
     * @param modelName
     * @param archiveId
     * @return
     */
    public Document getMaxSxhDocuments(String modelName, String archiveId);

    /**
     * 获取档案最大柜号
     *
     * @return
     */
    public Integer getArchivePosition();

    /**
     * 根据柜号获取柜号中最大格号
     *
     * @param setCabinetSno
     * @return
     */
    public Integer getMaxCellId(Integer setCabinetSno);

    /**
     * 根据格号获取最大盒号
     *
     * @param cellId
     * @return
     */
    public Integer getMaxBox(Integer cellId, Integer cabinetSno);

    /**
     * 根据盒号判断该盒是否放满
     *
     * @param boxId
     * @return
     */
    public boolean isBoxFull(Integer boxId, Integer cellId, Integer cabinetSno);

    /**
     * 判断格子是否已满
     *
     * @param cellId
     * @param cabinetSno
     * @return
     */
    public boolean isCellFull(Integer cellId, Integer cabinetSno);

    /**
     * 获取字表中移交单号最大值
     *
     * @param tableName 字表名称
     * @return
     */
    public int maxYjdh(String tableName, String nd, String ywjc, String dwjc);

    /**
     * 根据id更新字表的移交单号
     *
     * @param tableName
     * @param id
     */
    public void updateYjdhById(String tableName, String id, String value);

    /**
     * 根据用户的部门编码生成13位档号
     *
     * @param archive
     * @param userId
     * @return
     */
    public Archive createDhByArchive(Archive archive, String userId);

    /**
     * 根据卷内更新案卷的页数
     *
     * @param sum
     */
    public void updateArchiveYsByDoc(int sum, String archiveId);

    /**
     * 判断boxId在是否已占用
     *
     * @param boxId
     * @return
     */
    public boolean isExistBoxId(Integer boxId,String mlh,String modelName);

    /**
     * 根据Hql语句对archive进行更新
     *
     * @param hql     语句
     * @param objects 参数
     */
    public void upDateArchiveByHql(String hql, Object... objects);

    /**
     * 获取档案的年度
     *
     * @param modelName 模型名
     * @return
     */
    List getArchiveNd(String modelName);

    /**
     * 获取档案的目录号
     * @param modelName 业务模型名
     * @return
     */
    List getArchiveMlh(String modelName);

    /**
     * 获取档案的盒号
     *
     * @param modelName 模型名
     * @param nd        年度
     * @param dh        档号
     * @param mlh       目录号
     * @param boxId     盒号
     * @param cfwz      存放位置
     * @return
     */
    List getBox(String modelName, String nd, String dh, String mlh, String boxId, String cfwz);

    /**
     * 删除档案的盒号
     *
     * @param boxIds    盒号信息
     * @param modelName 业务模型名
     * @param nd        年度
     * @param dh        档号
     * @param mlh       目录号
     * @param cfwz      存放位置
     * @return
     */
    void deleteArchiveBoxId(String[] boxIds, String modelName, String nd, String dh, String mlh, String cfwz);

    /**
     * 保存档案盒号的存放位置
     * @param modelName 模型名
     * @param nd 年度
     * @param dh 档号
     * @param mlh 目录号
     * @param boxId 盒号
     * @param cfwz 存放位置
     */
    void updateArchiveBoxIDd(String modelName, String nd, String dh, String mlh, String boxId, String cfwz);
}
